@@ -41,6 +41,9 @@ def post(resource, payl=None):
                  See https://github.com/nicolaiarocci/eve/issues/74 for a
                  discussion, and a typical use case.
 
+    .. versionchanged:: 0.1.1
+        auth.request_auth_value is now used to store the auth_field value.
+
     .. versionchanged:: 0.1.0
        More robust handling of auth_field.
        Support for optional HATEOAS.
@@ -95,7 +98,11 @@ def post(resource, payl=None):
     # validation, and additional fields
     if payl is None:
         payl = payload()
-    for key, value in payl.items():
+
+    if isinstance(payl, dict):
+        payl = [payl]
+
+    for value in payl:
         document = []
         doc_issues = []
         try:
@@ -110,11 +117,10 @@ def post(resource, payl=None):
                 # and there's an Auth request active,
                 # inject the auth_field into the document
                 auth_field = resource_def['auth_field']
-                if auth_field:
-                    auth_field_value = getattr(app.auth, auth_field)
-                    if auth_field_value and request.authorization:
-                        document[auth_field] = auth_field_value
-
+                if app.auth and auth_field:
+                    request_auth_value = app.auth.request_auth_value
+                    if request_auth_value and request.authorization:
+                        document[auth_field] = request_auth_value
             else:
                 # validation errors added to list of document issues
                 doc_issues.extend(validator.errors)
@@ -138,8 +144,8 @@ def post(resource, payl=None):
         ids = app.data.insert(resource, documents)
 
     # build response payload
-    response = {}
-    for key, doc_issues in zip(payl.keys(), issues):
+    response = []
+    for doc_issues in issues:
         response_item = {}
         if len(doc_issues):
             response_item['status'] = config.STATUS_ERR
@@ -161,6 +167,9 @@ def post(resource, payl=None):
             for field in allowed_fields:
                 response_item[field] = document[field]
 
-        response[key] = response_item
+        response.append(response_item)
+
+    if len(response) == 1:
+        response = response.pop(0)
 
     return response, None, None, 200
