@@ -100,6 +100,16 @@ class TestGet(TestBase):
         resource = response['_items']
         self.assertEqual(len(resource), 1)
 
+    def test_get_where_mongo_combined_date(self):
+        where = '{"$and": [{"ref": "%s"}, {"created": \
+                {"$gte": "Tue, 01 Oct 2013 00:59:22 GMT"}}]}' % self.item_name
+        response, status = self.get(self.known_resource,
+                                    '?where=%s' % where)
+        self.assert200(status)
+
+        resource = response['_items']
+        self.assertEqual(len(resource), 1)
+
     def test_get_mongo_query_blacklist(self):
         where = '{"$where": "this.ref == ''%s''"}' % self.item_name
         response, status = self.get(self.known_resource,
@@ -111,8 +121,6 @@ class TestGet(TestBase):
                                     '?where=%s' % where)
         self.assert400(status)
 
-    # TODO need more tests here, to verify that the parser is behaving
-    # correctly
     def test_get_where_python_syntax(self):
         where = 'ref == %s' % self.item_name
         response, status = self.get(self.known_resource, '?where=%s' % where)
@@ -121,6 +129,15 @@ class TestGet(TestBase):
         resource = response['_items']
         self.assertEqual(len(resource), 1)
 
+    def test_get_where_python_syntax1(self):
+        where = 'ref == %s and created>="Tue, 01 Oct 2013 00:59:22 GMT"' \
+                % self.item_name
+        response, status = self.get(self.known_resource, '?where=%s' % where)
+        self.assert200(status)
+
+        resource = response['_items']
+        self.assertEqual(len(resource), 1)
+
     def test_get_projection(self):
         projection = '{"prog": 1}'
         response, status = self.get(self.known_resource, '?projection=%s' %
@@ -245,13 +262,15 @@ class TestGet(TestBase):
         response, status = self.parse_response(r)
         self.assertGet(response, status)
 
-    def assertGet(self, response, status):
+    def assertGet(self, response, status, resource=None):
         self.assert200(status)
 
         links = response['_links']
         self.assertEqual(len(links), 4)
         self.assertHomeLink(links)
-        self.assertResourceLink(links, self.known_resource)
+        if not resource:
+            resource = self.known_resource
+        self.assertResourceLink(links, resource)
         self.assertNextLink(links, 2)
 
         resource = response['_items']
@@ -329,6 +348,18 @@ class TestGet(TestBase):
         content = json.loads(r.get_data())
         self.assertTrue('location' in content['_items'][0]['person'])
 
+        # Test that it works with item endpoint too
+        r = self.test_client.get('%s/%s/%s' % (invoices['url'],
+                                               self.invoice_id,
+                                               '?embedded=%s' % embedded))
+        self.assert200(r.status_code)
+        content = json.loads(r.get_data())
+        self.assertTrue('location' in content['person'])
+
+    def test_get_nested_resource(self):
+        response, status = self.get('users/overseas')
+        self.assertGet(response, status, 'users_overseas')
+
 
 class TestGetItem(TestBase):
 
@@ -431,6 +462,81 @@ class TestGetItem(TestBase):
         response, status = self.parse_response(r)
         self.assertItemResponse(response, status)
 
+    def test_getitem_embedded(self):
+        # We need to assign a `person` to our test invoice
+        _db = self.connection[MONGO_DBNAME]
+
+        fake_contact = self.random_contacts(1)
+        fake_contact_id = _db.contacts.insert(fake_contact)[0]
+        _db.invoices.update({'_id': ObjectId(self.invoice_id)},
+                            {'$set': {'person': fake_contact_id}})
+
+        invoices = self.domain['invoices']
+
+        # Test that we get 400 if can't parse dict
+        embedded = 'not-a-dict'
+        r = self.test_client.get('%s/%s/%s' % (invoices['url'],
+                                               self.invoice_id,
+                                               '?embedded=%s' % embedded))
+        self.assert400(r.status_code)
+
+        # Test that doesn't come embedded if asking for a field that
+        # isn't embedded (global setting is True by default)
+        embedded = '{"person": 1}'
+        r = self.test_client.get('%s/%s/%s' % (invoices['url'],
+                                               self.invoice_id,
+                                               '?embedded=%s' % embedded))
+        self.assert200(r.status_code)
+        content = json.loads(r.get_data())
+        self.assertTrue(content['person'], self.item_id)
+
+        # Set field to be embedded
+        invoices['schema']['person']['data_relation']['embeddable'] = True
+
+        # Test that global setting applies even if field is set to embedded
+        invoices['embedding'] = False
+        r = self.test_client.get('%s/%s/%s' % (invoices['url'],
+                                               self.invoice_id,
+                                               '?embedded=%s' % embedded))
+        self.assert200(r.status_code)
+        content = json.loads(r.get_data())
+        self.assertTrue(content['person'], self.item_id)
+
+        # Test that it works
+        invoices['embedding'] = True
+        r = self.test_client.get('%s/%s/%s' % (invoices['url'],
+                                               self.invoice_id,
+                                               '?embedded=%s' % embedded))
+        self.assert200(r.status_code)
+        content = json.loads(r.get_data())
+        self.assertTrue('location' in content['person'])
+
+        # Test that it ignores a bogus field
+        embedded = '{"person": 1, "not-a-real-field": 1}'
+        r = self.test_client.get('%s/%s/%s' % (invoices['url'],
+                                               self.invoice_id,
+                                               '?embedded=%s' % embedded))
+        self.assert200(r.status_code)
+        content = json.loads(r.get_data())
+        self.assertTrue('location' in content['person'])
+
+        # Test that it ignores a real field with a bogus value
+        embedded = '{"person": 1, "inv_number": "not-a-real-value"}'
+        r = self.test_client.get('%s/%s/%s' % (invoices['url'],
+                                               self.invoice_id,
+                                               '?embedded=%s' % embedded))
+        self.assert200(r.status_code)
+        content = json.loads(r.get_data())
+        self.assertTrue('location' in content['person'])
+
+        # Test that it works with item endpoint too
+        r = self.test_client.get('%s/%s/%s' % (invoices['url'],
+                                               self.invoice_id,
+                                               '?embedded=%s' % embedded))
+        self.assert200(r.status_code)
+        content = json.loads(r.get_data())
+        self.assertTrue('location' in content['person'])
+
 
 class TestHead(TestBase):
 
