@@ -10,6 +10,9 @@ from redis import Redis
 
 redis = Redis()
 
+def test(value):
+    print "inside", value
+    return "$" + value
 
 class TAuth(TokenAuth):
     def check_auth(self, token, allowed_roles, resource, method):
@@ -66,6 +69,8 @@ def posting_r(documents):
 
 
 app = Eve(validator=Validator, redis=redis)
+
+app.config['CONV'] = {'string': str}
 #app.config['DOMAIN']['contacts']['auth_username_field'] = 'name'
 #app.on_get_contacts += resource_gotit
 #app.on_get += gotit
